Creating a release
====================

1. Update release date and version in `CHANGELOG.md` and commit.

2. Then tag the new release:
    git tag v0.4.0 -a
    <enter something like "Release v0.4.0">
    git push origin v0.4.0

3. Then update `CHANGELOG.md` again, commit and push.
